package com.caimei.modules.order.service.impl;

import com.caimei.modules.club.entity.Page;
import com.caimei.modules.order.dao.*;
import com.caimei.modules.order.entity.*;
import com.caimei.modules.order.service.NewOrderService;
import com.caimei.modules.order.service.OrderUserInfoService;
import com.caimei.utils.AppKeys;
import com.caimei.utils.AppUtils;
import com.caimei.utils.NewOrderStatus;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class NewOrderServiceImpl implements NewOrderService {
    @Autowired
    private NewOrderDao newOrderDao;
    @Autowired
    private CmDiscernReceiptDao cmDiscernReceiptDao;
    @Autowired
    private CmReturnedPurchaseDao cmReturnedPurchaseDao;
    @Autowired
    private CmReceiptOrderRelationDao cmReceiptOrderRelationDao;
    @Autowired
    private NewShopOrderDao newShopOrderDao;
    @Autowired
    private OrderUserInfoService orderUserInfoService;
    @Autowired
    private NewOrderProductDao newOrderProductDao;
    @Autowired
    private CmPayShopRecordDao cmPayShopRecordDao;
    @Autowired
    private OrderInvoiceDao orderInvoiceDao;
    @Value("${malladmin.domain}")
    private String domain;

    @Override
    public Page<NewOrder> findList(NewOrder newOrder, Page page) {
        PageHelper.startPage(page.getIndex(), page.getPageSize());
        List<NewOrder> orderList = newOrderDao.findList(newOrder);
        List<Integer> oId = orderList.stream().map(NewOrder::getOrderID).collect(Collectors.toList());
        //看看这些订单有哪些是返佣订单 返回他们的orderID
        List<Integer> orderIds = null;
        if (CollectionUtils.isNotEmpty(oId)) {
            orderIds = cmDiscernReceiptDao.findRebateOrderID(orderList.stream().map(NewOrder::getOrderID).collect(Collectors.toList()));
        }
        //从查询到的订单列表中 找到正在退款中的订单集合
        List<Integer> orderIdsInReturn = null;
        List<Integer> orderIdsInApplyReturn = null;//查询可以申请退款的订单ID
        if (CollectionUtils.isNotEmpty(oId)) {
            orderIdsInReturn = cmReturnedPurchaseDao.findOrderIDInReturnPurchase(oId);
            orderIdsInApplyReturn = cmReturnedPurchaseDao.findOrderIDsInApplyReturnFlag(oId);
        }
        for (NewOrder order : orderList) {
            if (orderIds != null && orderIds.contains(order.getOrderID())) {
                order.setRebateOrder("1");
            } else {
                order.setRebateOrder("0");
                List<Integer> ids = cmReceiptOrderRelationDao.toAudit(order.getOrderID());
                if (ids != null && ids.size() > 0) {
                    order.setToAudit("1");
                }
            }
            if (orderIdsInReturn != null && orderIdsInReturn.contains(order.getOrderID())) {
                order.setReturnedPurchaseStatus("1");
            } else {
                order.setReturnedPurchaseStatus("0");
            }
            if (orderIdsInApplyReturn != null && orderIdsInApplyReturn.contains(order.getOrderID())) {
                order.setApplyReturnedPurchaseFlag("0");
            } else {
                order.setApplyReturnedPurchaseFlag("1");
            }

            List<NewShopOrder> shopOrders = order.getNewShopOrders();
            if (shopOrders != null && shopOrders.size() == 1) {
                order.setShopName(shopOrders.get(0).getShopName());
            }
            int count = 0;
            for (NewShopOrder shopOrder : order.getNewShopOrders()) {
                shopOrder.setOrderID(order.getOrderID());
                shopOrder.setOrderNo(order.getOrderNo());
                shopOrder.setOrderType(Integer.valueOf(order.getOrderType()));
                shopOrder.setReceiver(order.getReceiver());
                shopOrder.setOrderSource(order.getOrderSource());
                shopOrder.setOrderTime(order.getOrderTime());
                shopOrder.setBuyer(order.getBuyer());
                if (shopOrder.getShopID() != 998) {
                    count++;
                }

                Integer shopOrderID = shopOrder.getShopOrderID();//子订单ID
                //通过子订单ID查询子订单信息
                NewShopOrder newShopOrder = newShopOrderDao.get(shopOrderID);
                if (null != newShopOrder) {
                    shopOrder.setFee(newShopOrder.getFee());
                    shopOrder.setShouldPayProduct(newShopOrder.getShouldPayProduct());
                } else {
                    shopOrder.setFee(0d);
                    shopOrder.setShouldPayProduct(0d);
                }
            }
            //一个子订单只有一个商品时,不可拆分
            if (order.getProductCount() == null) {
                order.setProductCount(1);
            }
            if (order.getProductCount() <= count) {
                order.setSplitFlag("0");
            }
        }
        Page<NewOrder> orderPage = new Page<>(orderList);
        return orderPage;
    }

    @Override
    public NewOrder get(String id) {
        NewOrder newOrder = newOrderDao.get(id);
        List<Integer> l = new ArrayList<>();
        l.add(newOrder.getOrderID());
        List<Integer> orderIds = cmDiscernReceiptDao.findRebateOrderID(l);
        if (orderIds.contains(newOrder.getOrderID()))
            newOrder.setRebateOrder("1");
        else
            newOrder.setRebateOrder("0");
        if (null != newOrder) {
            //获取订单客户
            OrderUserInfo orderUserInfo = orderUserInfoService.findByOrderID(newOrder.getOrderID());
            if (null != orderUserInfo) {
                newOrder.setBpOrderUserinfo(orderUserInfo);
            }
            //获取订单商品
            List<NewOrderProduct> list = new ArrayList<>();
            List<NewShopOrder> shopOrders = newShopOrderDao.findListByOrderID(newOrder.getOrderID());
            if (CollectionUtils.isNotEmpty(shopOrders)) {
                for (NewShopOrder shopOrder : shopOrders) {
                    List<NewOrderProduct> pList = newOrderProductDao.findListByShopOrderID(shopOrder.getShopOrderID());
                    list.addAll(pList);
                    shopOrder.setNewOrderProducts(pList);
                    if (pList.stream().anyMatch(p -> p.getProductID().intValue() == 999)) shopOrder.setPostFeeCos("1");
                    pList.stream().forEach(item -> {
                        if (NewOrderStatus.hasReturn(newOrder.getStatus())) {
                            Integer returningNum = newOrderProductDao.getReturningNum(item.getOrderProductID());
                            Integer returnedNum = newOrderProductDao.getReturnedNum(item.getOrderProductID());
                            item.setReturningNum(returningNum);
                            item.setReturnedNum(returnedNum);
                        }
                        /**确认收货信息*/
                        if (NewOrderStatus.hasReceived(newOrder.getStatus())) {
                            Integer receivedNum = newOrderProductDao.getReceivedNum(item.getOrderProductID());
                            item.setReceivedNum(receivedNum);
                        }
                        item.setProductImage(AppUtils.getProductImageURL(item.getProductImage(), AppKeys.ORIGINAL_PICTURE, domain));
                    });
                    Double payed = cmPayShopRecordDao.sumByShopOrderID(shopOrder.getShopOrderID());
                    shopOrder.setPayed(payed);
                }
                newOrder.setNewShopOrders(shopOrders);
            }
            if (CollectionUtils.isNotEmpty(list)) {
                newOrder.setOrderProduct(list);
                double freight = 0D;
                double totalAddedValueTax = 0D;
                for (NewOrderProduct op : list) {
                    if (op.getProductID().intValue() == 999) { //邮费商品
                        freight += op.getPrice();
                    }
                    totalAddedValueTax += op.getTotalAddedValueTax();
                }
                if ("1".equals(newOrder.getFreePostFlag())) newOrder.setFreight(freight);
                newOrder.setTotalAddedValueTax(totalAddedValueTax);
            }
            shopOrders.sort((so1, so2) -> {
                //给子订单排序  邮费排在最后  其余的按shopOrderID  asc
                if ("1".equals(so1.getPostFeeCos())) return 1;
                return so1.getShopOrderID() - so2.getShopOrderID();
            });
            //获取订单发票
            OrderInvoice orderInvoice = orderInvoiceDao.getWithorderId(newOrder.getOrderID() + "");
            if (null != orderInvoice) {
                newOrder.setOrderInvoice(orderInvoice);
            }
        }
        return newOrder;
    }
}
