package com.caimei.modules.products.controller;

import com.caimei.modules.club.entity.Page;
import com.caimei.modules.products.entity.CmMallOrganizeProducts;
import com.caimei.modules.products.entity.CmMallProductsClassify;
import com.caimei.modules.products.service.CmMallOrganizeProductsService;
import com.caimei.modules.products.service.CmMallProductsClassifyService;
import com.caimei.utils.JsonModel;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.Date;
import java.util.List;
import java.util.regex.Pattern;

/**
 * 小程序商品分类Controller
 *
 * @author lijun
 * @version 2019-12-03
 */
@Controller
@RequestMapping(value = "/product/cmMallProductsClassify")
public class CmMallProductsClassifyController {

    @Autowired
    private CmMallProductsClassifyService cmMallProductsClassifyService;
    @Autowired
    private CmMallOrganizeProductsService cmMallOrganizeProductsService;

    /**
     * 商品分类列表
     */
    @ResponseBody
    @RequestMapping(value = {"list"})
    public JsonModel list(CmMallProductsClassify cmMallProductsClassify, Page page) {
        PageHelper.startPage(page.getIndex(), page.getPageSize());
        List<CmMallProductsClassify> productsClassifyList = cmMallProductsClassifyService.findList(cmMallProductsClassify);
        Page<CmMallProductsClassify> classifyPage = new Page<>(productsClassifyList);
        return JsonModel.newInstance().success(classifyPage);
    }

    /**
     * 编辑回显
     *
     * @param id
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "form")
    public JsonModel form(Integer id) {
        CmMallProductsClassify mallProductsClassify = cmMallProductsClassifyService.get(id);
        return JsonModel.newInstance().success(mallProductsClassify);
    }

    /**
     * 编辑,保存
     *
     * @param cmMallProductsClassify
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "save", method = RequestMethod.POST)
    public JsonModel save(@RequestBody CmMallProductsClassify cmMallProductsClassify) {
        JsonModel jsonModel = JsonModel.newInstance();
        //保存商品名字不能重复
        List<CmMallProductsClassify> productsClassifyListByName = cmMallProductsClassifyService.getProductsClassifyListByName(cmMallProductsClassify);
        if (CollectionUtils.isNotEmpty(productsClassifyListByName) && productsClassifyListByName.size() > 0) {
            return jsonModel.error("分类名称不能重复");
        }
        //判断该商品是是否选择的是停用，如果停用判断该分类下是否存在商品
        if (StringUtils.equals("2", cmMallProductsClassify.getStatus())) {
            CmMallOrganizeProducts cmMallOrganizeProducts = new CmMallOrganizeProducts();
            cmMallOrganizeProducts.setOrganizeID(cmMallProductsClassify.getOrganizeID());
            cmMallOrganizeProducts.setClassifyID(String.valueOf(cmMallProductsClassify.getId()));
            List<CmMallOrganizeProducts> list1 = cmMallOrganizeProductsService.findList(cmMallOrganizeProducts);
            if (CollectionUtils.isNotEmpty(list1)) {
                return jsonModel.error("该分类中还存在商品，请把该分类的商品转移到别的分类后，再停用该分类");
            }
        }

        Date date = new Date();
        if (cmMallProductsClassify.getId() == null) {//是新增
            cmMallProductsClassify.setAddTime(date);
            cmMallProductsClassify.setDelFlag("0");
        }
        cmMallProductsClassify.setUpdateTime(date);
        /*//修改图片全路径
        ImageUploadInfo saveImageSerivce = new ImageUploadInfo();
        String photoServer = Global.getConfig("photoServer");
        String classifyImage = cmMallProductsClassify.getClassifyImage();
        if (StringUtils.isNotBlank(classifyImage) && !classifyImage.startsWith("http:") && !classifyImage.startsWith("https:")) {
            classifyImage = Encodes.urlDecode(classifyImage);
            String realPath = UploadImageUtils.getAbsolutePath(classifyImage);
            int pointerIndex = realPath.lastIndexOf(".");
            try {
                saveImageSerivce = UploadUtils.saveImageSerivce(realPath, pointerIndex, realPath);
                cmMallProductsClassify.setClassifyImage(photoServer + saveImageSerivce.getSource());
            } catch (Exception e) {
                logger.error("图片上传错误:" + e.toString(), e);
            }
        }*/
        cmMallProductsClassifyService.save(cmMallProductsClassify);
        return jsonModel.success();
    }

    /**
     * 启用,关闭
     *
     * @param id 分类id
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "switchClassify")
    public JsonModel switchClassify(Integer id) {
        CmMallProductsClassify mallProductsClassify = cmMallProductsClassifyService.get(id);
        if (mallProductsClassify.getStatus().equals("1")) {
            mallProductsClassify.setStatus("2");//1启用,2停用
        } else {
            mallProductsClassify.setStatus("1");//1启用,2停用
        }
        mallProductsClassify.setUpdateTime(new Date());
        cmMallProductsClassifyService.updateStatus(mallProductsClassify);//更新会所表数据
        return JsonModel.newInstance().success();
    }

    /**
     * 批量更新排序值
     *
     * @param newProducSorttList (分类id-排序值,...)
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "batchSaveSort")
    public JsonModel batchSaveSort(String newProducSorttList) {
        JsonModel jsonModel = JsonModel.newInstance();
        try {
            String[] newPageLists = newProducSorttList.split(",");
            for (String list : newPageLists) {
                String[] split = list.split("-");
                if (split.length == 1 || split.length < 1) {
                    return jsonModel.error("排序值不能为空！");
                }
                String s = split[1];//判断是否是数字，或者为空
                if (StringUtils.isNotEmpty(s)) {
                    if (isInteger(s)) {
                        if (StringUtils.equals("0", s)) {
                            return jsonModel.error("排序值只能填写大于等于1的整数");
                        }
                        String id = split[0];
                        String sort = split[1];
                        cmMallProductsClassifyService.saveSort(sort, id);
                    } else {
                        return jsonModel.error("排序值只能为数字");
                    }
                } else {
                    return jsonModel.error("排序值不能为空！");
                }
            }
            return jsonModel.success("更新排序成功", "");
        } catch (Exception e) {
            return jsonModel.error("更新排序失败");
        }
    }

    public static boolean isInteger(String str) {
        Pattern pattern = Pattern.compile("^[-\\+]?[\\d]*$");
        return pattern.matcher(str).matches();
    }
}