package com.caimei.modules.products.entity;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.hibernate.validator.constraints.Length;

import java.io.Serializable;
import java.util.Date;

/**
 * 小程序商城商品Entity
 *
 * @author lijun
 * @version 2019-12-04
 */
public class CmMallOrganizeProducts implements Serializable {

    private static final long serialVersionUID = 1L;
    private Integer id;
    private String classifyID;        // 对应cm_mall_products_classify商品分类表id
    private String organizeID;        // 组织ID,具体对应cm_mall_organize表ID
    private String productID;        // 商品ID,具体对应product表
    private String normalPrice;        // 市场价
    private String costPrice;        // 成本价
    private String retailPrice;        // 售价
    private String minBuyNumber;        // 最小起订量
    private String preferredProduct;        // 是否是优选商品：0不是优选,1优选商品
    private String commonlyProduct;        // 是否是常用商品：0不是常用,1常用商品
    private String preferentialProduct;        // 是否是星范精品：0不是特惠,1星范精品商品
    private String validFlag;        // 商品状态,1已上架,2已下架
    private String preferredProductSort;        //（优选排序）排序默认为空,排序优先级1最高，空最后
    private String commonlyProductSort;        //（常用排序）排序默认为空,排序优先级1最高,空最后
    private String preferentialProductSort;        //（精品排序）排序默认为空,排序优先级1最高,空最后
    private Date addTime;        // 添加时间
    private Date updateTime;        // 更新时间
    private Integer modules;     //第几个模块

    //非小程序商城商品信息
    private String mainImage;//商品图片
    private String productName;//商品名称
    private String shopName;//供应商名称
    private String productClassifyName;//商品分类名字

    private String itemsList;//添加商品字符串
    private String existsFlag;//是否已存在小程序商品中 1已存在，其他都为不存在

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    @Length(min = 0, max = 11, message = "对应cm_mall_products_classify商品分类表id长度必须介于 0 和 11 之间")
    public String getClassifyID() {
        return classifyID;
    }

    public void setClassifyID(String classifyID) {
        this.classifyID = classifyID;
    }

    @Length(min = 0, max = 11, message = "组织ID,具体对应cm_mall_organize表ID长度必须介于 0 和 11 之间")
    public String getOrganizeID() {
        return organizeID;
    }

    public void setOrganizeID(String organizeID) {
        this.organizeID = organizeID;
    }

    @Length(min = 0, max = 11, message = "商品ID,具体对应product表长度必须介于 0 和 11 之间")
    public String getProductID() {
        return productID;
    }

    public void setProductID(String productID) {
        this.productID = productID;
    }

    public String getNormalPrice() {
        return normalPrice;
    }

    public void setNormalPrice(String normalPrice) {
        this.normalPrice = normalPrice;
    }

    public String getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(String costPrice) {
        this.costPrice = costPrice;
    }

    public String getRetailPrice() {
        return retailPrice;
    }

    public void setRetailPrice(String retailPrice) {
        this.retailPrice = retailPrice;
    }

    @Length(min = 0, max = 11, message = "最小起订量长度必须介于 0 和 11 之间")
    public String getMinBuyNumber() {
        return minBuyNumber;
    }

    public void setMinBuyNumber(String minBuyNumber) {
        this.minBuyNumber = minBuyNumber;
    }

    @Length(min = 0, max = 1, message = "是否是优选商品：0不是优选,1优选商品长度必须介于 0 和 1 之间")
    public String getPreferredProduct() {
        return preferredProduct;
    }

    public void setPreferredProduct(String preferredProduct) {
        this.preferredProduct = preferredProduct;
    }

    @Length(min = 0, max = 1, message = "是否是常用商品：0不是常用,1常用商品长度必须介于 0 和 1 之间")
    public String getCommonlyProduct() {
        return commonlyProduct;
    }

    public void setCommonlyProduct(String commonlyProduct) {
        this.commonlyProduct = commonlyProduct;
    }

    @Length(min = 0, max = 1, message = "是否是星范精品：0不是特惠,1星范精品商品长度必须介于 0 和 1 之间")
    public String getPreferentialProduct() {
        return preferentialProduct;
    }

    public void setPreferentialProduct(String preferentialProduct) {
        this.preferentialProduct = preferentialProduct;
    }

    @Length(min = 0, max = 2, message = "商品状态,1已上架,2已下架长度必须介于 0 和 2 之间")
    public String getValidFlag() {
        return validFlag;
    }

    public void setValidFlag(String validFlag) {
        this.validFlag = validFlag;
    }

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    public Date getAddTime() {
        return addTime;
    }

    public void setAddTime(Date addTime) {
        this.addTime = addTime;
    }

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getMainImage() {
        return mainImage;
    }

    public void setMainImage(String mainImage) {
        this.mainImage = mainImage;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getShopName() {
        return shopName;
    }

    public void setShopName(String shopName) {
        this.shopName = shopName;
    }

    public String getProductClassifyName() {
        return productClassifyName;
    }

    public void setProductClassifyName(String productClassifyName) {
        this.productClassifyName = productClassifyName;
    }

    public String getPreferredProductSort() {
        return preferredProductSort;
    }

    public void setPreferredProductSort(String preferredProductSort) {
        this.preferredProductSort = preferredProductSort;
    }

    public String getCommonlyProductSort() {
        return commonlyProductSort;
    }

    public void setCommonlyProductSort(String commonlyProductSort) {
        this.commonlyProductSort = commonlyProductSort;
    }

    public String getPreferentialProductSort() {
        return preferentialProductSort;
    }

    public void setPreferentialProductSort(String preferentialProductSort) {
        this.preferentialProductSort = preferentialProductSort;
    }

    public String getItemsList() {
        return itemsList;
    }

    public void setItemsList(String itemsList) {
        this.itemsList = itemsList;
    }

    public String getExistsFlag() {
        return existsFlag;
    }

    public void setExistsFlag(String existsFlag) {
        this.existsFlag = existsFlag;
    }

    public Integer getModules() {
        return modules;
    }

    public void setModules(Integer modules) {
        this.modules = modules;
    }
}