package com.caimei.modules.shiro.service.impl;

import com.caimei.modules.order.entity.NewOrderProduct;
import com.caimei.modules.shiro.dao.HomePageDao;
import com.caimei.modules.shiro.service.HomePageService;
import com.caimei.utils.AppUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class HomePageServiceImpl implements HomePageService {
    @Autowired
    private HomePageDao homePageDao;
    @Value("${malladmin.domain}")
    private String domain;

    @Override
    public Map<String, Object> receivableAmount(String endTime, String startTime, Integer organizeID) {
        Map<String, Object> map = new HashMap();
        //订单总额
        Long payTotalFee = homePageDao.findTotalFee(endTime, startTime, organizeID);
        //余额支付总金额
        Long balancePayFee = homePageDao.findBalance(endTime, startTime, organizeID);
        //已收总金额
        Long associateAmount = homePageDao.findAssociate(endTime, startTime, organizeID);
        Long amountReceived = balancePayFee + associateAmount;
        //未收金额
        long uncollected = payTotalFee - amountReceived;
        map.put("payTotalFee", payTotalFee);
        map.put("amountReceived", amountReceived);
        map.put("uncollected", uncollected);
        return map;
    }

    @Override
    public Map<String, Object> orderQuantity(String endTime, String startTime, Integer organizeID) {
        Map<String, Object> map = new HashMap();
        DecimalFormat df = new DecimalFormat("0%");
        //订单总数量
        Integer count = homePageDao.orderQuantity(endTime, startTime, "", organizeID);
        //已收款数量
        Integer received = homePageDao.orderQuantity(endTime, startTime, "3", organizeID);
        //部分收款数量
        Integer portion = homePageDao.orderQuantity(endTime, startTime, "2", organizeID);
        //未收数量
        Integer uncollected = homePageDao.orderQuantity(endTime, startTime, "1", organizeID);
        map.put("count", count);
        map.put("received", received);
        map.put("portion", portion);
        map.put("uncollected", uncollected);
        return map;
    }

    @Override
    public Map<String, Object> sale(Integer organizeID) {
        Map<String, Object> map = new HashMap();
        List<String> list1 = new ArrayList();
        List<Long> list2 = new ArrayList();
        Map<String, String> map6 = CalendarUtils(-5);
        Long totalFee6 = homePageDao.findTotalFee(map6.get("endTime"), map6.get("startTime"), organizeID);
        list1.add(map6.get("month"));
        list2.add(totalFee6);

        Map<String, String> map5 = CalendarUtils(-4);
        Long totalFee5 = homePageDao.findTotalFee(map5.get("endTime"), map5.get("startTime"), organizeID);
        list1.add(map5.get("month"));
        list2.add(totalFee5);

        Map<String, String> map4 = CalendarUtils(-3);
        Long totalFee4 = homePageDao.findTotalFee(map4.get("endTime"), map4.get("startTime"), organizeID);
        list1.add(map4.get("month"));
        list2.add(totalFee4);

        Map<String, String> map3 = CalendarUtils(-2);
        Long totalFee3 = homePageDao.findTotalFee(map3.get("endTime"), map3.get("startTime"), organizeID);
        list1.add(map3.get("month"));
        list2.add(totalFee3);

        Map<String, String> map2 = CalendarUtils(-1);
        Long totalFee2 = homePageDao.findTotalFee(map2.get("endTime"), map2.get("startTime"), organizeID);
        list1.add(map2.get("month"));
        list2.add(totalFee2);

        Map<String, String> map1 = CalendarUtils(0);
        Long totalFee1 = homePageDao.findTotalFee(map1.get("endTime"), map1.get("startTime"), organizeID);
        list1.add(map1.get("month"));
        list2.add(totalFee1);

        map.put("month", list1);
        map.put("payTotalFee", list2);
        return map;
    }

    @Override
    public List<NewOrderProduct> commodity(String endTime, String startTime, Integer organizeID) {
        List<NewOrderProduct> commodity = homePageDao.commodity(endTime, startTime, organizeID);
        for (NewOrderProduct orderProduct : commodity) {
            orderProduct.setProductImage(AppUtils.getProductImageURL(orderProduct.getProductImage(), 0, domain));
        }
        return commodity;
    }

    public Map<String, String> CalendarUtils(Integer money) {
        Map<String, String> map = new HashMap();
        //2、获取本月第一天凌晨开始时间00:00:00和最后一天的最后一刻时间23:59:59
        Calendar cal = Calendar.getInstance();
        //当前日期月份
        cal.add(Calendar.MONTH, money);
        //设置时间格式为yyyy-MM-dd HH:mm:ss
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        int month = cal.get(Calendar.MONTH) + 1;
        map.put("month", "" + month + "月");
        //获取到本月起始日
        int actualMinimum = cal.getActualMinimum(Calendar.DAY_OF_MONTH);
        //获取到本月结束日
        int actualMaximum = cal.getActualMaximum(Calendar.DAY_OF_MONTH);
        //设置本月起始日的年月日时分秒格式
        cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONDAY), actualMinimum, 00, 00, 00);
        //打印本月起始日的年月日时分秒格式
        map.put("startTime", sdf.format(cal.getTime()));
        //设置本月结束日的年月日时分秒格式
        cal.set(cal.get(Calendar.YEAR), cal.get(Calendar.MONDAY), actualMaximum, 23, 59, 59);
        //打印本月结束日的年月日时分秒格式
        map.put("endTime", sdf.format(cal.getTime()));
        return map;
    }
}
